use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006001
use Test::Spelling 0.12;
use Pod::Wordlist;

add_stopwords(<DATA>);
all_pod_files_spelling_ok(qw( bin lib  ));
__DATA__
shantanu
bhadoria
CBusDevicePath
CDeviceAddress
Datasheet
dev
libi
smbus
xs
readByteData
writeByteData
processCall
readByte
readWordData
writeByte
writeQuick
writeWordData
readNBytes
Shantanu
Bhadoria
at
cpan
dott
org
Neil
Bowers
neil
lib
Device
SMBus
